Enum ScheduleCondition

pub enum ScheduleCondition {
    Immediately {
        situation: ProperFilename,
    },
    LocalNaiveTimeWindow {
        priority: Option<Priority>,
        situation: ProperFilename,
        stop_start: Option<Vec<String>>,
        repeatedly: bool,
        move_when_time_window_ends: bool,
        from: LocalNaiveTime,
        to: LocalNaiveTime,
    },
    Inactive,
}

Variants



Immediately

Run jobs in this queue once right away

Fields

situation: ProperFilename

A description of the situation during which jobs in this queue are executed; all jobs of the same context (and same key) are grouped together and evaluated to “summary-” file names with this string appended. Meant to reflect conditions that might influence the results; e.g. “immediate” or “night”.



LocalNaiveTimeWindow

Run jobs in this queue between the given times on every day (except when one of the times is not valid or ambiguous on a given day due to DST changes). Jobs started before the end of the window are finished, though.

Fields

priority: Option<Priority>

The priority of this queue–it is added to the priority of jobs in this queue. By default, 1.5 is used.

situation: ProperFilename

A description of the situation during which jobs in this queue are executed; all jobs of the same context (and same key) are grouped together and evaluated to “summary-” file names with this string appended. Meant to reflect conditions that might influence the results; e.g. “immediate” or “night”.

stop_start: Option<Vec<String>>

A command and arguments, run with “stop” at the from time and with “start” when done / at the to time.

repeatedly: bool

If true, run the BenchmarkingJobs in this queue until their own count reaches zero or the time window runs out (each job is rescheduled to the end of the queue after a run, meaning the jobs are alternating). If false, each job is run once and then moved to the next queue.

move_when_time_window_ends: bool

If true, when time runs out, move all remaining jobs to the next queue; if false, the jobs remain and are scheduled again in the same time window on the next day.

from: LocalNaiveTime

Times in the time zone that the daemon is running with (to change that, set TZ env var to area/city, or the default time zone via dpkg-reconfigure).



Inactive

A queue that is never run and never emptied, to add to the end of the queue pipeline to take up jobs that have been expelled from the second last queue, for informational purposes.

Implementations

Source

impl ScheduleCondition

pub const TIMED_QUEUE_DEFAULT_PRIORITY: Priority

pub fn is_inactive(&self) -> bool

Whether this queue will never run its jobs

pub fn time_range(&self) -> Option<(LocalNaiveTime, LocalNaiveTime)>

pub fn stop_start(&self) -> Option<&[String]>

pub fn move_when_time_window_ends(&self) -> bool

Returns true if the condition offers that flag and it is true

pub fn situation(&self) -> Option<&ProperFilename>

pub fn priority(&self) -> Option<Priority>

pub fn is_runnable_at( &self, reference_time: DateTime<Local>, ) -> Option<Option<DateTimeRange<Local>>>

Returns an optional time window (given if runnable due to being in this time window) if runnable