pub struct BenchmarkingCommand {
pub target_name: ProperDirname,
pub subdir: PathBuf,
pub command: String,
pub arguments: Vec<String>,
pub pre_exec_bash_code: PreExecLevel2,
}Expand description
What command to run on the target project to execute a benchmarking run; the env variables configured in CustomParameters are set when running this command.
Fields
target_name: ProperDirnameThe name is matched on the target_name field in
JobTemplate, and it is used as the first path segment below
output_base_dir for storing the results. It will also be
shown by evobench list.
subdir: PathBufRelative path to the subdirectory (provide “.” for the top level of the working directory) where to run the command
command: StringName or path to the command to run, e.g. “make”
arguments: Vec<String>Arguments to the command, e.g. “bench”
pre_exec_bash_code: PreExecLevel2Bash shell code to run before executing this target. E.g. to
source a Python virtual env or defining env variables. set -meuo pipefail and IFS= are enabled. Execution flow must
leave at the end of the string. This is executed after code
declared via the global target_pre_exec_bash_code field, if
any. Note that this value (together with the other values in
BenchmarkingCommand) is copied into the job, and
evobench wd enter will use the copy from the time the
job was started, not the current value here!