pub struct QueuesConfig {
pub run_queues_basedir: Option<TildePath<PathBuf>>,
pub pipeline: Vec<(ProperFilename, ScheduleCondition)>,
pub erroneous_jobs_queue: Option<(ProperFilename, ScheduleCondition)>,
pub done_jobs_queue: Option<(ProperFilename, ScheduleCondition)>,
pub view_jobs_max_len: usize,
}Fields
run_queues_basedir: Option<TildePath<PathBuf>>If not given, ~/.evobench/queues/ is used. Also used for
locking the run action of evobench, to ensure only one
benchmarking job is executed at the same time–if you
configure multiple such directories then you don’t have this
guarantee any more. Supports ~/
for specifying the home directory.
pipeline: Vec<(ProperFilename, ScheduleCondition)>The queues to use (file names, without ‘/’), and their scheduled execution condition
erroneous_jobs_queue: Option<(ProperFilename, ScheduleCondition)>The queue where to put jobs when they run out of
error_budget (if None is given, the jobs will be dropped–
silently unless verbose flag is given). Should be of
scheduling type Inactive (or perhaps a future messaging
queue).
done_jobs_queue: Option<(ProperFilename, ScheduleCondition)>The queue where to put jobs when they are finished
successfully (if None is given, the jobs will be dropped–
silently unless verbose flag is given).
view_jobs_max_len: usizeHow many jobs to show in the extra queues
(erroneous_jobs_queue and done_jobs_queue) when no --all
option is given
Implementations
Sourceimpl QueuesConfig
impl QueuesConfig
pub fn run_queues_basedir( &self, create_if_not_exists: bool, global_app_state_dir: &GlobalAppStateDir, ) -> Result<PathBuf>