Struct RunConfigOpts

pub struct RunConfigOpts {
    pub queues: Arc<QueuesConfig>,
    pub working_directory_pool: Arc<WorkingDirectoryPoolOpts>,
    pub target_pre_exec_bash_code: Option<Arc<str>>,
    pub targets: Vec<Arc<BenchmarkingTarget>>,
    pub job_template_lists: BTreeMap<KString, Vec<JobTemplateOpts>>,
    pub benchmarking_job_settings: Arc<BenchmarkingJobSettingsOpts>,
    pub eval_settings: Arc<EvalSettings>,
    pub remote_repository: RemoteRepositoryOpts,
    pub output_dir: OutputDirOpts,
    pub versioned_datasets_base_dir: Option<Arc<TildePath<PathBuf>>>,
    pub commit_tags_regex: Option<SerializableRegex>,
    /* private fields */
}
Direct representation of the evobench config file

Fields

queues: Arc<QueuesConfig>working_directory_pool: Arc<WorkingDirectoryPoolOpts>target_pre_exec_bash_code: Option<Arc<str>>

Bash shell code to run before executing any of the targets. E.g. to source a Python virtual env or defining env variables. set -meuo pipefail and IFS= are enabled. Execution flow must leave at the end of the string.

targets: Vec<Arc<BenchmarkingTarget>>

What command to run on the target project to execute a benchmarking run; the env variables configured in CustomParameters are set when running this command.

job_template_lists: BTreeMap<KString, Vec<JobTemplateOpts>>

A set of named job template lists, referred to by name from remote_branch_names_for_poll or from the command line (evobench insert templates). Each job template in a list generates a separate benchmark run for each commit that is inserted. The order defines in which order the jobs are inserted (which means the job generated from the first template is scheduled first, at least if priorities are the same). priority is added to whatever priority the inserter asks for, and initial_boost is added to the job for its first run only.

benchmarking_job_settings: Arc<BenchmarkingJobSettingsOpts>

Each job receives a copy of these settings after expansion

eval_settings: Arc<EvalSettings>

Settings for calling evobench-eval

remote_repository: RemoteRepositoryOpts

Information on the remote repository of the target project

output_dir: OutputDirOpts

Where the output files should be placed.

versioned_datasets_base_dir: Option<Arc<TildePath<PathBuf>>>

Optional directory holding directories whose name is taken from the (optional, depending on the configuration) DATASET custom variable (hacky to mis-use a custom variable for this?), inside which are directories named after git revision names (tags or commit ids), the latest which is an ancestor or the commit itself to be benchmarked, i.e. $versioned_datasets_base_dir/$DATASET/$best_rev_name. The resolved path (only when both this option and DATASET are provided) is stored in the DATASET_DIR env var when calling the benchmarking entry point of the client app. Supports ~/ for specifying the home directory.

commit_tags_regex: Option<SerializableRegex>

A regular expression matching those Git tags that should be passed to the target in the COMMIT_TAGS env variable (as comma-separated strings). By default, all tags are passed.

Implementations

Source

impl RunConfigOpts

pub fn check( &self, global_app_state_dir: &GlobalAppStateDir, ) -> Result<RunConfig>

Don’t take ownership since RunConfigWithReload can’t give it